@@ -10,7 +10,6 @@ import re
 import shutil
 import subprocess
 import sys
-import tempfile
 import warnings
 from collections import OrderedDict
 from dataclasses import dataclass, field
@@ -166,6 +165,7 @@ class Runtime:
         require_module: bool = False,
         max_retries: int = 0,
         environ: dict[str, str] | None = None,
+        verbosity: int = 0,
     ) -> None:
         """Initialize Ansible runtime environment.
 
@@ -187,12 +187,17 @@ class Runtime:
                             Default is 0, no retries.
         :param environ: Environment dictionary to use, if undefined
                         ``os.environ`` will be copied and used.
+        :param verbosity: Verbosity level to use.
         """
         self.project_dir = project_dir or Path.cwd()
         self.isolated = isolated
         self.max_retries = max_retries
         self.environ = environ or os.environ.copy()
         self.plugins = Plugins(runtime=self)
+        self.verbosity = verbosity
+
+        self.initialize_logger(level=self.verbosity)
+
         # Reduce noise from paramiko, unless user already defined PYTHONWARNINGS
         # paramiko/transport.py:236: CryptographyDeprecationWarning: Blowfish has been deprecated
         # https://github.com/paramiko/paramiko/issues/2038
@@ -236,9 +241,24 @@ class Runtime:
         # Monkey patch ansible warning in order to use warnings module.
         Display.warning = warning
 
+    def initialize_logger(self, level: int = 0) -> None:
+        """Set up the global logging level based on the verbosity number."""
+        verbosity_map = {
+            -2: logging.CRITICAL,
+            -1: logging.ERROR,
+            0: logging.WARNING,
+            1: logging.INFO,
+            2: logging.DEBUG,
+        }
+        # Unknown logging level is treated as DEBUG
+        logging_level = verbosity_map.get(level, logging.DEBUG)
+        _logger.setLevel(logging_level)
+        # Use module-level _logger instance to validate it
+        _logger.debug("Logging initialized to level %s", logging_level)
+
     def _add_sys_path_to_collection_paths(self) -> None:
         """Add the sys.path to the collection paths."""
-        if not self.isolated and self.config.collections_scan_sys_path:
+        if self.config.collections_scan_sys_path:
             for path in sys.path:
                 if (
                     path not in self.config.collections_paths
@@ -436,7 +456,7 @@ class Runtime:
         if isinstance(collection, Path):
             collection = str(collection)
         # As ansible-galaxy install is not able to automatically determine
-        # if the range requires a pre-release, we need to manuall add the --pre
+        # if the range requires a pre-release, we need to manually add the --pre
         # flag when needed.
         matches = version_re.search(collection)
 
@@ -456,13 +476,13 @@ class Runtime:
         cmd.append(f"{collection}")
 
         _logger.info("Running from %s : %s", Path.cwd(), " ".join(cmd))
-        run = self.run(
+        process = self.run(
             cmd,
             retry=True,
             env={**self.environ, ansible_collections_path(): ":".join(cpaths)},
         )
-        if run.returncode != 0:
-            msg = f"Command returned {run.returncode} code:\n{run.stdout}\n{run.stderr}"
+        if process.returncode != 0:
+            msg = f"Command returned {process.returncode} code:\n{process.stdout}\n{process.stderr}"
             _logger.error(msg)
             raise InvalidPrerequisiteError(msg)
 
@@ -472,30 +492,7 @@ class Runtime:
         destination: Path | None = None,
     ) -> None:
         """Build and install collection from a given disk path."""
-        if not self.version_in_range(upper="2.11"):
-            self.install_collection(path, destination=destination, force=True)
-            return
-        # older versions of ansible able unable to install without building
-        with tempfile.TemporaryDirectory() as tmp_dir:
-            cmd = [
-                "ansible-galaxy",
-                "collection",
-                "build",
-                "--output-path",
-                str(tmp_dir),
-                str(path),
-            ]
-            _logger.info("Running %s", " ".join(cmd))
-            run = self.run(cmd, retry=False)
-            if run.returncode != 0:
-                _logger.error(run.stdout)
-                raise AnsibleCommandError(run)
-            for archive_file in os.listdir(tmp_dir):
-                self.install_collection(
-                    str(Path(tmp_dir) / archive_file),
-                    destination=destination,
-                    force=True,
-                )
+        self.install_collection(path, destination=destination, force=True)
 
     # pylint: disable=too-many-branches
     def install_requirements(  # noqa: C901
@@ -529,9 +526,11 @@ class Runtime:
                 "ansible-galaxy",
                 "role",
                 "install",
-                "-vr",
+                "-r",
                 f"{requirement}",
             ]
+            if self.verbosity > 0:
+                cmd.extend(["-" + ("v" * self.verbosity)])
             if self.cache_dir:
                 cmd.extend(["--roles-path", f"{self.cache_dir}/roles"])
 
@@ -543,8 +542,9 @@ class Runtime:
                 _logger.info("Running %s", " ".join(cmd))
 
                 result = self.run(cmd, retry=retry)
+                _logger.debug(result.stdout)
                 if result.returncode != 0:
-                    _logger.error(result.stdout)
+                    _logger.error(result.stderr)
                     raise AnsibleCommandError(result)
 
         # Run galaxy collection install works on v2 requirements.yml
@@ -553,8 +553,10 @@ class Runtime:
                 "ansible-galaxy",
                 "collection",
                 "install",
-                "-v",
             ]
+            if self.verbosity > 0:
+                cmd.extend(["-" + ("v" * self.verbosity)])
+
             for collection in reqs_yaml["collections"]:
                 if isinstance(collection, dict) and collection.get("type", "") == "git":
                     _logger.info(
@@ -582,8 +584,8 @@ class Runtime:
                     retry=retry,
                     env={**os.environ, "ANSIBLE_COLLECTIONS_PATH": ":".join(cpaths)},
                 )
+                _logger.debug(result.stdout)
                 if result.returncode != 0:
-                    _logger.error(result.stdout)
                     _logger.error(result.stderr)
                     raise AnsibleCommandError(result)
 
@@ -638,14 +640,14 @@ class Runtime:
                 destination=destination,
             )
 
-        if Path("galaxy.yml").exists():
+        if (self.project_dir / "galaxy.yml").exists():
             if destination:
                 # while function can return None, that would not break the logic
                 colpath = Path(
-                    f"{destination}/ansible_collections/{colpath_from_path(Path.cwd())}",
+                    f"{destination}/ansible_collections/{colpath_from_path(self.project_dir)}",
                 )
                 if colpath.is_symlink():
-                    if os.path.realpath(colpath) == Path.cwd():
+                    if os.path.realpath(colpath) == str(Path.cwd()):
                         _logger.warning(
                             "Found symlinked collection, skipping its installation.",
                         )
@@ -765,7 +767,7 @@ class Runtime:
             msg = "Unexpected ansible configuration"
             raise RuntimeError(msg) from exc
 
-        alterations_list = [
+        alterations_list: list[tuple[list[str], str, bool]] = [
             (library_paths, "plugins/modules", True),
             (roles_path, "roles", True),
         ]
@@ -786,12 +788,12 @@ class Runtime:
                 if must_be_present:
                     continue
                 path.mkdir(parents=True, exist_ok=True)
-            if path not in path_list:
+            if str(path) not in path_list:
                 path_list.insert(0, str(path))
 
         if library_paths != self.config.DEFAULT_MODULE_PATH:
             self._update_env("ANSIBLE_LIBRARY", library_paths)
-        if collections_path != self.config.collections_paths:
+        if collections_path != self.config.default_collections_path:
             self._update_env(ansible_collections_path(), collections_path)
         if roles_path != self.config.default_roles_path:
             self._update_env("ANSIBLE_ROLES_PATH", roles_path)
@@ -934,7 +936,10 @@ def _get_galaxy_role_ns(galaxy_infos: dict[str, Any]) -> str:
 
 def _get_galaxy_role_name(galaxy_infos: dict[str, Any]) -> str:
     """Compute role name from meta/main.yml."""
-    return galaxy_infos.get("role_name", "")
+    result = galaxy_infos.get("role_name", "")
+    if not isinstance(result, str):
+        return ""
+    return result
 
 
 def search_galaxy_paths(search_dir: Path) -> list[str]:
